<template>
    <view class="c-nav-bar">
        <AtNavBar
            :title="title"
            leftIconType="chevron-left"
            :onClickLeftIcon="evt=>goBack()"
            :rightFirstIconType="dropNav ? 'bullet-list' : ''"
            :onClickRgIconSt="evt=>dropMenu()"
        />
        <view
            class="c-nav-bar-drop"
            v-show="dropShow"
        >
            <view class="inner">
                <view class="arrow"></view>
                <view class="box">
                    <view
                        class="c-nav-bar-drop-item item"
                        v-for="(nav,index) in dropNav"
                        :key="index"
                        @tap="evt=>goNav(nav)"
                    >{{nav.title}}</view>
                </view>
            </view>
        </view>
    </view>
</template>

<script>
import Taro from '@tarojs/taro';
import { AtNavBar } from 'taro-ui-vue';
import './cNavBar.scss';

export default {
    name: 'CNavBar',
    components: {
        AtNavBar,
    },
    props: {
        title: String,
        dropNav: Array,
    },
    data() {
        return {
            dropShow: false,
            dropTimer: -1,
            dropActive: false,
        };
    },
    methods: {
        goBack() {
            window.history.go(-1);
        },
        goNav(nav) {
            if (!nav.url) {
                return;
            }
            this.dropShow = false;
            setTimeout(() => {
                Taro.navigateTo({ url: nav.url });
            }, 0);
        },
        dropMenu() {
            this.dropShow = !this.dropShow;
            this.dropActive = true;
            clearTimeout(this.dropTimer);
            this.dropTimer = setTimeout(() => {
                this.dropActive = false;
            }, 500);
        },
        outCloseMenu(evt) {
            (() => {
                // 未打开时，忽略
                if (!this.dropShow) {
                    return;
                }
                // 刚刚打开的一段时间内，忽略
                if (this.dropActive) {
                    return;
                }
                // 点击了菜单项，忽略
                if (evt.target.className.indexOf('c-nav-bar-drop-item') >= 0) {
                    return;
                }
                // 执行关闭
                this.dropShow = false;
            })();
        },
    },
    mounted() {
        Taro.eventCenter.on('pageTouchstart', this.outCloseMenu);
        Taro.eventCenter.on('pageClick', this.outCloseMenu);
    },
    beforeDestroy() {
        Taro.eventCenter.off('pageTouchstart', this.outCloseMenu);
        Taro.eventCenter.off('pageClick', this.outCloseMenu);
    },
};
</script>